@@ -16,11 +16,14 @@ from tensorwrap import config
 # Path Shortener:
 from tensorwrap.module import Module
 from tensorwrap.version import __version__
+from tensorwrap.experimental.serialize import save_model, load_model
 from tensorwrap.experimental.wrappers import function
+from tensorwrap.ops import expand_dims
 
 # JAX Built-ins:
 from jax.numpy import array as Variable
 from jax.numpy import float16, float32, float64
 from jax.numpy import int16, int32, int64
-from jax.numpy import matmul, square, abs, mean
-from jax.numpy import reshape
\ No newline at end of file
+from jax.numpy import matmul, square, abs, mean, sum
+from jax.numpy import reshape
+from jax.numpy import arange as range
\ No newline at end of file
